# This file was autogenerated from a .units.py file
# via `make units`
'''
Ancient Greek units.
https://en.wikipedia.org/wiki/Ancient_Greek_units_of_measurement
All units of length are based on an Attic
measurement (pous = 296 mm).
'''

from noether.core import Unit, UnitSet

from ..fundamental import meter

pous = πούς = Unit(
    meter * 0.296,
    ['pous', 'πούς'],
    info='Ancient greek foot, as defined in Athens (though varying regionally).')


daktylos = δάκτυλος = Unit(
    pous / 16,
    ['daktylos', 'δάκτυλος'],
    info='Ancient Greek; finger.')
kondylos = κόνδυλος = Unit(
    daktylos * 2,
    ['kondylos', 'κόνδυλος'],
    info='Ancient Greek; knuckle.')
palaiste = palaistē = παλαιστή = doron = dōron = δῶρον = Unit(
    daktylos * 4,
    ['palaiste', 'palaistē', 'παλαιστή', 'doron', 'dōron', 'δῶρον'],
    info='Ancient Greek; palm.')
dichas = διχάς = hemipodion = hēmipodion = ἡμιπόδιον = Unit(
    daktylos * 8,
    ['dichas', 'διχάς', 'hemipodion', 'hēmipodion', 'ἡμιπόδιον'],
    info='Ancient Greek; half-foot.')
lichas = λιχάς = Unit(
    daktylos * 10,
    ['lichas', 'λιχάς'],
    info='Ancient Greek; distance from tip of thumb to tip of outstretched index finger.')
orthodoron = orthodōron = ὀρθόδωρον = Unit(
    daktylos * 11,
    ['orthodoron', 'orthodōron', 'ὀρθόδωρον'],
    info='Ancient Greek; width of a straight hand.')
spithame = spithamē = σπιθαμή = Unit(
    daktylos * 12,
    ['spithame', 'spithamē', 'σπιθαμή'],
    info='Ancient Greek; span of all fingers.')
pygme = pygmē = πυγμή = Unit(
    daktylos * 18,
    ['pygme', 'pygmē', 'πυγμή'],
    info='Ancient Greek; forearm')
pygon = pygōn = πυγών = Unit(
    daktylos * 20,
    ['pygon', 'pygōn', 'πυγών'],
    info='Ancient Greek; elbow to fist')
pechys = pēchys = πῆχυς = Unit(
    daktylos * 24,
    ['pechys', 'pēchys', 'πῆχυς'],
    info='Ancient Greek; cubit (elbow to tip of hand)')

haploun_bema = haploun_bēma = ἁπλοῦν_βῆμα = Unit(
    pous * 2.5,
    ['haploun_bema', 'haploun_bēma', 'ἁπλοῦν_βῆμα'],
    info='Ancient Greek; step')
diploun_bema = diploun_bēma = διπλοῦν_βῆμα = bema = bēma = βῆμα = Unit(
    pous * 5,
    ['diploun_bema', 'diploun_bēma', 'διπλοῦν_βῆμα', 'bema', 'bēma', 'βῆμα'],
    info='Ancient Greek; pace')
orgyia = ὄργυια = Unit(
    pous * 6,
    ['orgyia', 'ὄργυια'],
    info='Ancient Greek; fathom')
kalamos = κάλαμος = akaina = ἄκαινα = dekapous = δεκάπους = Unit(
    pous * 10,
    ['kalamos', 'κάλαμος', 'akaina', 'ἄκαινα', 'dekapous', 'δεκάπους'],
    info='Ancient Greek')
hamma = ἅμμα = Unit(
    pous * 60,
    ['hamma', 'ἅμμα'],
    info='Ancient Greek; knot')
plethron = πλέθρον = Unit(
    pous * 100,
    ['plethron', 'πλέθρον'],
    info='Ancient Greek; typical length of an athletic running-track')
stadion = στάδιον = Unit(
    pous * 600,
    ['stadion', 'στάδιον'],
    info='Ancient Greek; one eighth of a Roman mile')

diaulos = δίαυλος = Unit(
    stadion * 2,
    ['diaulos', 'δίαυλος'],
    info='Ancient Greek; ancient Olympic racing distance')
hippikon = ἱππικόν = Unit(
    stadion * 4,
    ['hippikon', 'ἱππικόν'],
    info='Ancient Greek; length of a hippodrome (horse racing stadium)')
milion = μίλιον = Unit(
    stadion * 8,
    ['milion', 'μίλιον'],
    info='Ancient Greek equiv. of a mile')
dolichos = δόλιχος = Unit(
    stadion * 12,
    ['dolichos', 'δόλιχος'],
    info='Ancient Greek; ancient Olympic "long race"')
parasanges = παρασάγγης = Unit(
    stadion * 30,
    ['parasanges', 'παρασάγγης'],
    info='Ancient Greek equiv. of a league; used to measure walking distance')
schoinos = σχοινός = Unit(
    stadion * 40,
    ['schoinos', 'σχοινός'],
    info='Ancient Greek, adopted from an Egyptian unit of surveying with knotted cords')
stage = Unit(
    stadion * 160,
    ['stage'],
    info='Ancient Greek')
